/**
 * @file
 * Do not let videos be played until accept Onetrust cookies.
 */

(function (Drupal) {

  'use strict';

  if (typeof(Drupal.youtubeCookies) === 'undefined') {
    Drupal.youtubeCookies = {};
  }

  /**
   * Informs whether youtube specific cookies are accepted or not.
   *
   * @returns {boolean}
   *   True when youtube cookies are accepted.
   */
  Drupal.youtubeCookies.oneTrustCookiesAccepted = function() {
    return typeof(OnetrustActiveGroups) !== 'undefined' && OnetrustActiveGroups.indexOf(drupalSettings.youtubeCookies.cookieCategory) !== -1;
  };

  /**
   * Setup youtube cookies integration for onetrust.
   */
  Drupal.youtubeCookies.setupOnetrust = function() {
    Drupal.youtubeCookies.setup(Drupal.youtubeCookies.oneTrustCookiesAccepted());
  };

  /**
   * Behavior description.
   */
  Drupal.behaviors.youtubeCookiesOneTrust = {
    attach: function (context, settings) {

      Drupal.youtubeCookies.setupOnetrust();

      /**
       * Setup youtube videos based in onetrust current values /  events.
       *
       * This code should run just once after the OneTrust cookies are accepted.
       * The reason an interval is used is because OneTrust variable is asynchronously
       * loaded and this is the way to notice when onetrust is loaded,
       * and no documentation of onetrust load events have been found for now
       * (which would prevent this workaround).
       *
       * @type {NodeJS.Timeout}
       */
      let youtubeOnetrustCookiesInterval = setInterval(function() {
        if (typeof(OneTrust) === 'undefined') {
          console.log("Can't find onetrust library to setup youtube lazyload, trying again...");
          return;
        }

        // Setup youtube videos when the cookies have been setup
        // earlier
        if (OneTrust.IsAlertBoxClosedAndValid()) {
          Drupal.youtubeCookies.setupOnetrust();
        }

        // Setup the youtube videos interactivity after setting up cookies.
        OneTrust.OnConsentChanged(Drupal.youtubeCookies.setupOnetrust);

        clearInterval(youtubeOnetrustCookiesInterval);

      }, 100);

    }
  };

} (Drupal));
