/**
 * @file
 * Do not let videos be played until accept Onetrust cookies.
 */


(function (Drupal) {

  'use strict';

  Drupal.youtubeCookies = {
    youtubeCookiesAccepted: false,
    youtubeNoCookiesUsed: false,
  };

  /**
   * Replace url of iframes.
   */
  Drupal.youtubeCookies.setYoutubeNoCookieUrl = function () {
    let videos = document.querySelectorAll('iframe[data-src*="youtube.com"],iframe[src*="youtube.com"],iframe[data-src*="youtu.be"],iframe[src*="youtu.be"]');
    const youtube_id_regexp = '[^\\s&\?\/\#]{11}';

    for (var video in Array.from(videos)) {
      let iframe = videos[video];
      var original_src =  typeof(iframe.src) === 'string' && iframe.src.length > 0 ? iframe.src : iframe.getAttribute('data-src');
      var video_id_matches = [];
      if (original_src.match('(youtube\.com\/embed\/)(' + youtube_id_regexp + ')')) {
        video_id_matches = original_src.match('(youtube\.com\/embed\/)(' + youtube_id_regexp + ')');
      }
      if (original_src.match('(youtu\.be\/)(' + youtube_id_regexp + ')')) {
        video_id_matches = original_src.match('(youtube\.com\/embed)|(youtu\.be\/)(' + youtube_id_regexp + ')');
      }
      else if (original_src.match('(youtube\.com\/watch%3Fv%3D)(' + youtube_id_regexp + ')')) {
        video_id_matches = original_src.match('(youtube\.com\/watch%3Fv%3D)(' + youtube_id_regexp + ')');
      }
      if (video_id_matches != null && video_id_matches.length > 0) {
        var video_id = video_id_matches[video_id_matches.length - 1];
        var attribute = typeof(iframe.src) === 'string' && iframe.src.length > 0 ? 'src' : 'data-src';
        videos[video].setAttribute('data-original-src', original_src);
        videos[video].setAttribute('data-original-src-attribute', attribute);
        videos[video].setAttribute(attribute, 'https://www.youtube-nocookie.com/embed/' + video_id + '?enablejsapi=1');
      }
    }
    Drupal.youtubeCookies.youtubeNoCookiesUsed = true;
  };

  /**
   * Set the youtube original urls to the iframes.
   *
   * Only works with videos that haven't been played yet.
   */
  Drupal.youtubeCookies.setYoutubeOriginalUrls = function() {
    var videos = document.querySelectorAll('iframe[data-original-src*="youtube.com"],iframe[data-original-src*="youtube.com"],iframe[data-original-src*="youtu.be"],iframe[data-original-src*="youtu.be"]');
    for (var video in Array.from(videos)) {
      var attribute = videos[video].getAttribute('data-original-src-attribute');
      videos[video].setAttribute(attribute, videos[video].getAttribute('data-original-src'));
    }
  };

  /**
   * Setup the youtube videos.
   *
   * Show / hide videos whether whether the
   * cookies have been accepted.
   */
  Drupal.youtubeCookies.setup = function(youtubeCookiesAccepted) {
    Drupal.youtubeCookies.youtubeCookiesAccepted = youtubeCookiesAccepted;
    if (Drupal.youtubeCookies.youtubeCookiesAccepted && Drupal.youtubeCookies.youtubeNoCookiesUsed) {
      Drupal.youtubeCookies.setYoutubeOriginalUrls();
    }
    else {
      Drupal.youtubeCookies.setYoutubeNoCookieUrl();
    }
  };

} (Drupal));
