<?php

namespace Drupal\youtube_cookies\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure youtube_cookies settings for this site.
 */
class SettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'youtube_cookies_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['youtube_cookies.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    $config = $this->config('youtube_cookies.settings');

    $form['cookie_category'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Cookie category'),
      '#description' => $this->t('The machine name of the cookie compliance category that must be accepted to play youtube videos.'),
      '#default_value' => $config->get('cookie_category'),
    ];

    $form['provider'] = [
      '#type' => 'select',
      '#title' => $this->t('Cookie compliance system'),
      '#description' => $this->t('The system that provides the cookie compliance features. Examples: onetrust, EU cookie compliance.'),
      '#default_value' => $config->get('provider'),
      '#options' => [
        'onetrust' => $this->t('One trust'),
        'eu_cookie_compliance' => $this->t('Eu cookie compliance'),
      ],
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('youtube_cookies.settings')
      ->set('cookie_category', $form_state->getValue('cookie_category'))
      ->set('provider', $form_state->getValue('provider'))
      ->save();
    parent::submitForm($form, $form_state);
  }

}
